# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# NOTE: also update perl-XML-LibXSLT to a compatible version, see
# http://bugzilla.redhat.com/469480
#
# In the meantime, we'll conflict with versions of perl-XML-LibXSLT that are too old

Conflicts:	perl-XML-LibXSLT < 1.70

Name:		perl-XML-LibXML
Summary:	Perl interface to the libxml2 library
Epoch:		1
Version:	2.0210
Release:	1.0.%{__distinit}%{__distvers}
# Note: some of the examples, scripts and tests are MIT-licensed but we don't package any of them
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/XML-LibXML
Source0:	https://cpan.metacpan.org/modules/by-module/XML/XML-LibXML-%{version}.tar.gz
Patch0:		XML-LibXML-2.0202-Parse-an-ampersand-entity-in-SAX-interface.patch
Patch1:		XML-LibXML-2.0209-no-Alien.patch
Patch10:	XML-LibXML-2.0115-UTF8.patch
Patch11:	XML-LibXML-2.0111-tests.patch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	glibc-common
BuildRequires:	libxml2-devel >= 2.7.6
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Config)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(ExtUtils::PkgConfig)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(Encode)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(IO::File)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(overload)
BuildRequires:	perl(parent)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(threads)
BuildRequires:	perl(Tie::Hash)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
BuildRequires:	perl(XML::NamespaceSupport) >= 1.07
BuildRequires:	perl(XML::SAX::Base)
BuildRequires:	perl(XML::SAX::DocumentLocator)
BuildRequires:	perl(XML::SAX::Exception)
BuildRequires:	perl(XSLoader)
# Test Suite
BuildRequires:	perl(Errno)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(lib)
BuildRequires:	perl(locale)
BuildRequires:	perl(POSIX)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(utf8)
BuildRequires:	perl(XML::SAX) >= 0.11
BuildRequires:	perl(XML::SAX::ParserFactory)
# Optional Tests
BuildRequires:	perl(Test::CPAN::Changes) >= 0.27
BuildRequires:	perl(Test::Differences)
BuildRequires:	perl(Test::Kwalitee)
BuildRequires:	perl(Test::LeakTrace)
BuildRequires:	perl(Test::Pod) >= 1.14
BuildRequires:	perl(Test::TrailingSpace)
BuildRequires:	perl(threads::shared)
BuildRequires:	perl(URI::file)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(perl -MConfig -e 'print $Config{version}'))
%endif
Requires:	perl(Data::Dumper)
Requires:	libxml2 >= 2.7.6
Requires(preun):perl-interpreter
# Run-require "perl-interpreter" because a triggerin script needs it
Requires:	perl-interpreter

# No epoch needed for perl-XML-LibXML-Common obsoletes/provides
Obsoletes:	perl-XML-LibXML-Common < %{version}-%{release}
Provides:	perl-XML-LibXML-Common = %{version}-%{release}
Obsoletes:	perl-XML-LibXML-XPathContext < %{version}-%{release}
Provides:	perl-XML-LibXML-XPathContext = %{version}-%{release}

# Don't "provide" private Perl libs
%{?perl_default_filter}

%description
This module implements a Perl interface to the Gnome libxml2 library, which
provides interfaces for parsing and manipulating XML files. This module allows
Perl programmers to make use of the highly capable validating XML parser and
the high performance DOM implementation.

%prep
%setup -q -n XML-LibXML-%{version}

# Fix parsing ampersand entities in SAX interface (CPAN RT#131498)
%patch -P 0 -p1

# Since Alien::Libxml2 is very heavy in terms of dependencies, use
# ExtUtils::PkgConfig instead
%patch -P 1

# Fix documentation character encoding
%patch -P 10

# Skip threads shared_clone test if threads::shared is too old
%patch -P 11

%build
SKIP_SAX_INSTALL=1 perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test RELEASE_TESTING=1

%triggerin -- perl-XML-SAX
for p in XML::LibXML::SAX::Parser XML::LibXML::SAX ; do
	perl -MXML::SAX -e "XML::SAX->add_parser(q($p))->save_parsers()" 2>/dev/null || :
done

%preun
if [ $1 -eq 0 ] ; then
	for p in XML::LibXML::SAX::Parser XML::LibXML::SAX ; do
		perl -MXML::SAX -e "XML::SAX->remove_parser(q($p))->save_parsers()" 2>/dev/null || :
	done
fi

%files
%license LICENSE
%doc Changes HACKING.txt README TODO
%{perl_vendorarch}/auto/XML/
%{perl_vendorarch}/XML/
%{_mandir}/man3/XML::LibXML.3*
%{_mandir}/man3/XML::LibXML::Attr.3*
%{_mandir}/man3/XML::LibXML::AttributeHash.3*
%{_mandir}/man3/XML::LibXML::Boolean.3*
%{_mandir}/man3/XML::LibXML::CDATASection.3*
%{_mandir}/man3/XML::LibXML::Comment.3*
%{_mandir}/man3/XML::LibXML::Common.3*
%{_mandir}/man3/XML::LibXML::Devel.3*
%{_mandir}/man3/XML::LibXML::DOM.3*
%{_mandir}/man3/XML::LibXML::Document.3*
%{_mandir}/man3/XML::LibXML::DocumentFragment.3*
%{_mandir}/man3/XML::LibXML::Dtd.3*
%{_mandir}/man3/XML::LibXML::Element.3*
%{_mandir}/man3/XML::LibXML::ErrNo.3*
%{_mandir}/man3/XML::LibXML::Error.3*
%{_mandir}/man3/XML::LibXML::InputCallback.3*
%{_mandir}/man3/XML::LibXML::Literal.3*
%{_mandir}/man3/XML::LibXML::Namespace.3*
%{_mandir}/man3/XML::LibXML::Node.3*
%{_mandir}/man3/XML::LibXML::NodeList.3*
%{_mandir}/man3/XML::LibXML::Number.3*
%{_mandir}/man3/XML::LibXML::PI.3*
%{_mandir}/man3/XML::LibXML::Parser.3*
%{_mandir}/man3/XML::LibXML::Pattern.3*
%{_mandir}/man3/XML::LibXML::Reader.3*
%{_mandir}/man3/XML::LibXML::RegExp.3*
%{_mandir}/man3/XML::LibXML::RelaxNG.3*
%{_mandir}/man3/XML::LibXML::SAX.3*
%{_mandir}/man3/XML::LibXML::SAX::Builder.3*
%{_mandir}/man3/XML::LibXML::SAX::Generator.3*
%{_mandir}/man3/XML::LibXML::Schema.3*
%{_mandir}/man3/XML::LibXML::Text.3*
%{_mandir}/man3/XML::LibXML::XPathContext.3*
%{_mandir}/man3/XML::LibXML::XPathExpression.3*

%changelog
* Wed Jan 24 2024 Paul Howarth <paul@city-fan.org> - 1:2.0210-1.0
- Update to 2.0210
  - Fix copying external entity from an ext_ent_handler handler (GH#81)
  - libxml-mm: Fix function prototypes in function pointers

* Wed Nov 29 2023 Paul Howarth <paul@city-fan.org> - 1:2.0209-3.0
- Restore compatibility with libxml-2.12.0 (#2251181)

* Sun Jul 16 2023 Paul Howarth <paul@city-fan.org> - 1:2.0209-1.0
- Update to 2.0209
  - t/35huge_mode.t: fix test with libxml2 2.11 (GH#80)
  - Add clearer reference to using cloneNode to extract node with namespaces
    (GH#74)
  - Initialize xmlValidCtxt (GH#73)

* Fri Jul 14 2023 Paul Howarth <paul@city-fan.org> - 1:2.0208-3.0
- Perl 5.38 rebuild

* Thu Jun 22 2023 Paul Howarth <paul@city-fan.org> - 1:2.0208-2.0
- Use SPDX-format license tag
- Avoid use of deprecated patch syntax

* Fri Sep 30 2022 Paul Howarth <paul@city-fan.org> - 1:2.0208-1.0
- Update to 2.0208
  - The createElementNS and setNamespace functions were getting confused by
    Readonly scalars (CPAN RT#144415)

* Thu Jun  2 2022 Paul Howarth <paul@city-fan.org> - 1:2.0207-6.0
- Perl 5.36 rebuild

* Mon May 24 2021 Paul Howarth <paul@city-fan.org> - 1:2.0207-2.0
- Perl 5.34 rebuild

* Sat Apr 17 2021 Paul Howarth <paul@city-fan.org> - 1:2.0207-1.0
- Update to 2.0207
  - Small clean-ups (GH#63)
- Use %%license unconditionally

* Tue Sep 15 2020 Paul Howarth <paul@city-fan.org> - 1:2.0206-1.0
- Update to 2.0206
  - Add expand_entities => 1 to the instantiation at lib/XML/LibXML/SAX.pm
    (CPAN RT#132759)
  - Update HACKING.txt

* Mon Jun 29 2020 Paul Howarth <paul@city-fan.org> - 1:2.0205-2.0
- Perl 5.32 rebuild

* Fri May  8 2020 Paul Howarth <paul@city-fan.org> - 1:2.0205-1.0
- Update to 2.0205
  - Add XML::LibXML to the XML/SAX/ParserDetails.ini configuration file upon
    installation (CPAN RT#132523, GH#49)
- Note that this RPM package manages SAX installation at package install and
  removal time, so build-time installation is turned off

* Tue Mar 17 2020 Paul Howarth <paul@city-fan.org> - 1:2.0204-1.0
- Update to 2.0204
  - Require a recent Alien::Libxml2 (CPAN RT#132129)

* Wed Mar 11 2020 Paul Howarth <paul@city-fan.org> - 1:2.0203-1.0
- Update to 2.0203
  - Use Alien::Base::Wrapper for better portability (GH#45)

* Tue Jan 28 2020 Paul Howarth <paul@city-fan.org> - 1:2.0202-2.0
- Fix parsing ampersand entities in SAX interface (CPAN RT#131498)

* Mon Jan 13 2020 Paul Howarth <paul@city-fan.org> - 1:2.0202-1.0
- Update to 2.0202
  - Disable loading external DTDs or external entities by default
  - Docs: Note that HTTPS doesn't work for schema-loading either
  - Allow to parse RelaxNG without accessing network
  - Allow to parse XML Schema without accessing network
  - Add Test-Count assertion count checking using
    https://metacpan.org/pod/Code::TidyAll::Plugin::TestCount

* Thu Jun  6 2019 Paul Howarth <paul@city-fan.org> - 1:2.0201-2.0
- Perl 5.30 rebuild

* Sun May 26 2019 Paul Howarth <paul@city-fan.org> - 1:2.0201-1.0
- Update to 2.0201
  - Set MIN_PERL_VERSION to 5.8.1
  - Alien::Libxml2 Makefile.PL clean-ups
  - Update the README for grammar and info
  - Link to XML-LibXML "by Example" (GH#36)

* Sun Mar 24 2019 Paul Howarth <paul@city-fan.org> - 1:2.0200-1.0
- Update to 2.0200
  - Convert to use Alien::Libxml2 (GH#30)
- Since Alien::Libxml2 is very heavy in terms of dependencies, use
  ExtUtils::PkgConfig instead

* Mon Feb 11 2019 Paul Howarth <paul@city-fan.org> - 1:2.0134-1.0
- Update to 2.0134
  - Fix overzealous POD escaping in the docs' synopses (GH#26)

* Thu Feb  7 2019 Paul Howarth <paul@city-fan.org> - 1:2.0133-1.0
- Update to 2.0133
  - Mark as working with libxml2 2.9.9 (and below)
  - Allow LibParser to be provided for all methods (GH#23)
  - Portability fixes by Reini Urban and others (GH#18)

* Fri Jan  4 2019 Paul Howarth <paul@city-fan.org> - 1:2.0132-5.0
- Rebuild for libxml2-2.9.9

* Fri Jun 29 2018 Paul Howarth <paul@city-fan.org> - 1:2.0132-4.0
- Perl 5.28 rebuild

* Wed Mar  7 2018 Paul Howarth <paul@city-fan.org> - 1:2.0132-3.0
- Rebuild for libxml2-2.9.8

* Fri Nov  3 2017 Paul Howarth <paul@city-fan.org> - 1:2.0132-2.0
- Rebuild for libxml2-2.9.7

* Mon Oct 30 2017 Paul Howarth <paul@city-fan.org> - 1:2.0132-1.0
- Update to 2.0132
  - Revert setNamespace() enhancements that broke some dependent tests:
    - Commit df9fdc6659cb2e4e9bc896e58c02dfd79b430fbb
    - Add t/48_rt123379_setNamespace.t

* Wed Oct 25 2017 Paul Howarth <paul@city-fan.org> - 1:2.0131-1.0
- Update to 2.0131
  - Re-include the missing *.pod documents (CPAN RT#123362)
  - Add t/pod-files-presence.t to test for it in the future
  - Fix use-after-free in Node::replaceChild() (CVE-2017-10672, #1470205, GH#8)

* Wed Oct 18 2017 Paul Howarth <paul@city-fan.org> - 1:2.0130-1.0
- Update to 2.0130
  - Fix the tests with libxml2-2.9.6 (CPAN RT#122958)
  - setNamespace() enhancements
- Upstream has dropped lots of documentation, perhaps unintentionally?

* Fri Oct  6 2017 Paul Howarth <paul@city-fan.org> - 1:2.0129-9.0
- Rebuild for libxml2-2.9.6

* Wed Sep 20 2017 Paul Howarth <paul@city-fan.org> - 1:2.0129-8.0
- Adapt to libxml2-2.9.5 (#1489529, CPAN RT#122958)

* Fri Aug  4 2017 Paul Howarth <paul@city-fan.org> - 1:2.0129-7.0
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Mon Jul 17 2017 Paul Howarth <paul@city-fan.org> - 1:2.0129-5.0
- Fix use-after-free by controlling the arguments to a replaceChild call
  (CVE-2017-10672, #1470205)

* Sat Jul 15 2017 Paul Howarth <paul@city-fan.org> - 1:2.0129-4.0
- BR: perl-interpreter rather than just perl
- BR: perl-generators unconditionally
- Add scriptlet dependencies on perl-interpreter

* Thu Jun 15 2017 Paul Howarth <paul@city-fan.org> - 1:2.0129-2.0
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally
- Skip Test::Kwalitee::Extra as it requires network access at build time

* Tue Mar 14 2017 Paul Howarth <paul@city-fan.org> - 1:2.0129-1.0
- Update to 2.0129
  - Add example/create-sample-html-document.pl (CPAN RT#117923)
  - Add support for the set_document_locator() SAX method
  - Make parsing of large perl strings much faster (GH#5)

* Tue Jan 10 2017 Paul Howarth <paul@city-fan.org> - 1:2.0128-2.0
- Test::Kwalitee::Extra now universally available, but this module's use of a
  build-time module Conftest requires Module::CPANTS::Analyse ≥ 0.96, which
  is still only available from Fedora 9 onwards

* Sun Jul 24 2016 Paul Howarth <paul@city-fan.org> - 1:2.0128-1.0
- Update to 2.0128
  - Make sure t/release-kwalitee.t and other tests do not run by default, only
    with AUTHOR_TESTING or RELEASE_TESTING specified (CPAN RT#115586,
    CPAN RT#115859)
- Explicitly run the release tests

* Sat Jun 25 2016 Paul Howarth <paul@city-fan.org> - 1:2.0126-1.0
- Update to 2.0126
  - Workaround CPAN RT#114638:
    - 2.9.4 broke XSD Schema support
    - https://rt.cpan.org/Public/Bug/Display.html?id=114638
    - https://github.com/shlomif/libxml2-2.9.4-reader-schema-regression
    - https://bugzilla.gnome.org/show_bug.cgi?id=766834
    - https://github.com/shlomif/perl-XML-LibXML/pull/1
  - Add t/release-kwalitee.t for testing CPANTS Kwalitee

* Tue May 31 2016 Paul Howarth <paul@city-fan.org> - 1:2.0125-1.0
- Update to 2.0125
  - Moved the repository from Mercurial and BitBucket to Git and GitHub:
    https://github.com/shlomif/perl-XML-LibXML

* Tue May 24 2016 Paul Howarth <paul@city-fan.org> - 1:2.0124-3.0
- Rebuild for libxml2 2.9.4

* Tue May 17 2016 Paul Howarth <paul@city-fan.org> - 1:2.0124-2.0
- BR: perl-generators where possible
- Simplify find commands using -delete

* Sat Feb 27 2016 Paul Howarth <paul@city-fan.org> - 1:2.0124-1.0
- Update to 2.0124
  - Fix XML::LibXML::Text->attributes() to return an empty list in list
    context (CPAN RT#112470)
- Disable threads test, prone to hanging due to list corruption

* Mon Dec  7 2015 Paul Howarth <paul@city-fan.org> - 1:2.0123-1.0
- Update to 2.0123
  - Get rid of an undef-warning in XML::LibXML::Reader (CPAN RT#106830)
  - Reword the documentation (CPAN RT#110116)

* Thu Nov 26 2015 Paul Howarth <paul@city-fan.org> - 1:2.0122-2.0
- Rebuild against the latest libxml2

* Tue Sep  1 2015 Paul Howarth <paul@city-fan.org> - 1:2.0122-1.0
- Update to 2.0122
  - Enable the memory test on cygwin as well as Linux (CPAN RT#104666)
  - Fix a typo in createElementNS (CPAN RT#106807)
- Explicitly BR: perl-devel, needed for EXTERN.h

* Thu Jun 25 2015 Paul Howarth <paul@city-fan.org> - 1:2.0121-5.0
- Perl 5.22 rebuild

* Sun May  3 2015 Paul Howarth <paul@city-fan.org> - 1:2.0121-1.0
- Update to 2.0121
  - Update Changes file to mention CVE-2015-3451

* Fri May  1 2015 Paul Howarth <paul@city-fan.org> - 1:2.0120-1.0
- Update to 2.0120
  - Replace the test for the previous change with a more meaningful one

* Thu Apr 23 2015 Paul Howarth <paul@city-fan.org> - 1:2.0119-1.0
- Update to 2.0119
  - Preserve unset options after a _clone() call (e.g: in load_xml())
    (CVE-2015-3451)

* Mon Feb  9 2015 Paul Howarth <paul@city-fan.org> - 1:2.0118-1.0
- Update to 2.0118
  - Add $Config{incpath} to the include paths on Win32 (CPAN RT#101944)

* Mon Oct 27 2014 Paul Howarth <paul@city-fan.org> - 1:2.0117-1.0
- Update to 2.0117
  - Support libxml2 builds with disabled xmlReader
  - Makefile.PL : don't require a recentish ExtUtils::MakeMaker (CPAN RT#83322)
  - Fix broken t/02parse.t with non-English locale with recent perls
    (CPAN RT#97805)
- Classify buildreqs by usage

* Thu Sep 11 2014 Paul Howarth <paul@city-fan.org> - 1:2.0116-4.0
- BR: perl(Test::CPAN::Changes) unconditionally
- Use %%license where possible

* Sat Apr 12 2014 Paul Howarth <paul@city-fan.org> - 1:2.0116-1.0
- Update to 2.0116
  - t/cpan-changes.t: minimum version of Test::CPAN::Changes; this is to
    avoid test failures such as:
    http://www.cpantesters.org/cpan/report/69ee1a2a-6c09-1014-be8f-3786912f2992
- Add buildreq perl(Test::CPAN::Changes) where possible

* Fri Apr 11 2014 Paul Howarth <paul@city-fan.org> - 1:2.0115-2.0
- Add buildreq perl(Test::TrailingSpace)
- Drop support for old distributions prior to FC-5:
  - Drop %%defattr, redundant since rpm 4.4
  - Run threads test unconditionally
  - BR: perl(Test::LeakTrace) unconditionally

* Thu Apr  3 2014 Paul Howarth <paul@city-fan.org> - 1:2.0115-1.0
- Update to 2.0115
  - Fix memory leaks and segfaults related to removal and insertion of DTD
    nodes (CPAN RT#80521)
  - Fix memory leak in $node->removeChildNodes
  - Fix double free when calling $node->addSibling with text nodes
    (CPAN RT#94149)
- Update UTF8 patch

* Fri Mar 14 2014 Paul Howarth <paul@city-fan.org> - 1:2.0113-1.0
- Update to 2.0113
  - Fix test failures with older libxml2 versions (CPAN RT#93852)

* Thu Mar 13 2014 Paul Howarth <paul@city-fan.org> - 1:2.0112-1.0
- Update to 2.0112
  - Fix segfaults when accessing attributes of DTD nodes (CPAN RT#71076)
  - Make $schema->validate work with elements; this uses
    xmlSchemaValidateOneElement under the hood (CPAN RT#93496)
  - Passing { recover => 2 } directly to load_html didn't work (CPAN RT#93429)
  - Apply patch to build with MSVC on Windows (CPAN RT#90064)

* Thu Mar  6 2014 Paul Howarth <paul@city-fan.org> - 1:2.0111-1.0
- Update to 2.0111
  - Skip t/40reader_mem_error.t with libxml2 < 2.7.4; the failure is probably
    due to a known double-free bug (CPAN RT#84564, Gnome Bug #447899)
  - Die if a file handle with an encoding layer returns more bytes than
    requested in parse_fh (CPAN RT#78448)
  - Make insertData, deleteData, replaceData work correctly with UTF-8 strings
  - Fix substringData (CPAN RT#88730)
  - Fix "Threads still failing?" bug report (CPAN RT#91800)
- Add patch to skip threads shared_clone test if threads::shared is too old

* Sat Feb  1 2014 Paul Howarth <paul@city-fan.org> - 1:2.0110-1.0
- Update to 2.0110
  - Add "use strict;" and "use warnings;" to all modules
  - MIN_PERL_VERSION
  - Add a LICENSE section to the POD

* Fri Jan 31 2014 Paul Howarth <paul@city-fan.org> - 1:2.0109-1.0
- Update to 2.0109
  - Fix for requiring XML::LibXML inside two loops in perl-5.19.6 and up
    (CPAN RT#92606)

* Tue Dec 17 2013 Paul Howarth <paul@city-fan.org> - 1:2.0108-1.0
- Update to 2.0108
  - Replace "local $^W" with "no warnings 'portable';" in t/15nodelist.t
    (CPAN RT#88017)
  - Fix hash key typo in SAX/Builder.pm (CPAN RT#91433)
  - Convert from "use base" to the more modern "use parent"

* Thu Oct 31 2013 Paul Howarth <paul@city-fan.org> - 1:2.0107-1.0
- Update to 2.0107
  - Add a unique_key method for namespace objects
    (https://bitbucket.org/shlomif/perl-xml-libxml/pull-request/24/)
  - Grammar fixes in the documentation (CPAN RT#89718)

* Tue Sep 17 2013 Paul Howarth <paul@city-fan.org> - 1:2.0106-1.0
- Update to 2.0106
  - Import croak from "use Carp;" to fix a missing croak definition
    (CPAN RT#88624)
  - Update Devel::CheckLib under "./inc" to 1.01 (should fix CPAN RT#81297)
- BR: perl(Carp)

* Sat Sep  7 2013 Paul Howarth <paul@city-fan.org> - 1:2.0105-1.0
- Update to 2.0105
  - Add convenience methods to the XML::LibXML::NodeList module
    - New method 'to_literal_delimited($separator)'
    - New method 'to_literal_list()'
  - Fix t/35huge_mode.t on libxml2 versions less than 2.7.0 (CPAN RT#88375)
  - Add toStringC14N_v1_1() to XML::LibXML::Node (CPAN RT#88254)

* Fri Aug 30 2013 Paul Howarth <paul@city-fan.org> - 1:2.0104-1.0
- Update to 2.0104
  - Use quoted version number in the SYNOPSIS (CPAN RT#88060)
  - Fix test failures when building with a directory component that contains
    whitespace (CPAN RT#86665)

* Thu Aug 22 2013 Paul Howarth <paul@city-fan.org> - 1:2.0103-1.0
- Update to 2.0103
  - Fix for test failures in t/40reader.t (CPAN RT#83779)

* Mon Aug 19 2013 Paul Howarth <paul@city-fan.org> - 1:2.0102-1.0
- Update to 2.0102
  - Fixed XPathContext memory leak on registerFunction (CPAN RT#83744)
  - Fixed replaceNode() segfault when copying DTD nodes with ATTLISTs
    (CPAN RT#80521)
  - Fix build failure on RHEL-5-64 (CPAN RT#83779)
- BR: perl(Test::LeakTrace) where possible
- Add patch to fix regression from putative fix for CPAN RT#83779, causing
  test failures in t/40reader.t

* Thu Aug 15 2013 Paul Howarth <paul@city-fan.org> - 1:2.0101-1.0
- Update to 2.0101
  - Fixed "HTML doctype differs for string/scalar input" (CPAN RT#87089)

* Wed Aug 14 2013 Paul Howarth <paul@city-fan.org> - 1:2.0100-1.0
- Update to 2.0100
  - Added the unique_key() method to XML::LibXML::Node
  - t/40reader.t: assigning from $@ to a lexical so it won't be over-ridden
    (CPAN RT#87830)

* Fri Jul 19 2013 Paul Howarth <paul@city-fan.org> - 1:2.0019-2.0
- Perl 5.18 rebuild

* Mon Jul  1 2013 Paul Howarth <paul@city-fan.org> - 1:2.0019-1.0
- Update to 2.0019
  - Correct typos (CPAN RT#86599)

* Mon May 13 2013 Paul Howarth <paul@city-fan.org> - 1:2.0018-1.0
- Update to 2.0018
  - Revert previous change of minimal version of libxml2, which proved to be
    unpopular and didn't prevent the CPAN test failures

* Thu May  9 2013 Paul Howarth <paul@city-fan.org> - 1:2.0017-1.0
- Update to 2.0017
  - Made the minimum version of libxml2 2.9.0 as previous versions were too
    buggy due to spurious CPAN test failures

* Fri Apr 19 2013 Paul Howarth <paul@city-fan.org> - 1:2.0016-2.0
- Rebuild for libxml2 2.9.1

* Mon Apr 15 2013 Paul Howarth <paul@city-fan.org> - 1:2.0016-1.0
- Update to 2.0016
  - Don't enable XML_PARSE_HUGE by default
    (https://bitbucket.org/shlomif/perl-xml-libxml/pull-request/19)

* Wed Dec  5 2012 Paul Howarth <paul@city-fan.org> - 1:2.0014-1.0
- Update to 2.0014
  - Got 40reader_mem_error.t to not fetch the external DTDs (CPAN RT#81703)

* Tue Dec  4 2012 Paul Howarth <paul@city-fan.org> - 1:2.0013-1.0
- Update to 2.0013
  - Fix a memory error (double-free) in XML::LibXML::Reader if we reached EOF
    and then called destroy (see t/40reader_mem_error.t)

* Fri Nov  9 2012 Paul Howarth <paul@city-fan.org> - 1:2.0012-1.0
- Update to 2.0012
  - Fix support for references to scalars with overloaded stringification
    magic (CPAN RT#77864)

* Thu Nov  8 2012 Paul Howarth <paul@city-fan.org> - 1:2.0011-1.0
- Update to 2.0011
  - Fix crash in removeChild() when not expanding entities (CPAN RT#80395)

* Thu Nov  1 2012 Paul Howarth <paul@city-fan.org> - 1:2.0010-1.0
- Update to 2.0010
  - Fix libxml2 detection in Strawberry Perl (CPAN RT#80540)
  - Passing debug (an undocumented option) to check_lib in Makefile.PL; this
    way we get more meaningful traces on perl Makefile.PL DEBUG=1

* Mon Oct 22 2012 Paul Howarth <paul@city-fan.org> - 1:2.0008-1.0
- Update to 2.0008
  - Fix build error when using non-standard libxml2 installation
    (CPAN RT#80332)

* Wed Oct 17 2012 Paul Howarth <paul@city-fan.org> - 1:2.0007-1.0
- Update to 2.0007
  - Fix for build failures on Windows with Microsoft Visual C++ (CPAN RT#80229)

* Sun Oct 14 2012 Paul Howarth <paul@city-fan.org> - 1:2.0006-1.0
- Update to 2.0006
  - When xml2-config returns several paths, the configuration failed
    (CPAN RT#80167)

* Sat Oct 13 2012 Paul Howarth <paul@city-fan.org> - 1:2.0005-1.0
- Update to 2.0005
  - Added t/style-trailing-space.t and removed trailing spaces
  - Add a check for the existence of included C headers (*.h) files in
    Makefile.PL to avoid failed compilations

* Tue Sep 11 2012 Paul Howarth <paul@city-fan.org> - 1:2.0004-1.2
- Rebuild for libxml2 2.9.0

* Mon Aug 20 2012 Paul Howarth <paul@city-fan.org> - 1:2.0004-1.1
- Rebuild for libxml2 2.9.0 (rc) in devel branches

* Tue Aug  7 2012 Paul Howarth <paul@city-fan.org> - 1:2.0004-1.0
- Update to 2.0004
  - Add a way to specify a different compiler to be used in the Makefile by
    calling Makefile.PL with the CC environment variable set to the path to the
    alternate compiler, e.g. «CC=/usr/bin/clang perl Makefile.PL»
  - LibXML.pm (_clone): fix typo in line_numbers handling
- Update UTF-8 patch

* Fri Jul 27 2012 Paul Howarth <paul@city-fan.org> - 1:2.0003-1.0
- Update to 2.0003
  - Fix a potential NULL dereference in xpath.c
  - Fix NodeList::item() calling a 1-indexed array reference
  - Add the scripts/tag-release.pl script to tag a release using Mercurial
- Update UTF-8 patch

* Sun Jul  8 2012 Paul Howarth <paul@city-fan.org> - 1:2.0002-1.0
- Update to 2.0002 (spelling fixes)

* Wed Jun 20 2012 Paul Howarth <paul@city-fan.org> - 1:2.0001-1.0
- Update to 2.0001
  - Remove the leftover perl-libxml-libxml.h from the distribution
    (CPAN RT#77924)

* Wed Jun 20 2012 Paul Howarth <paul@city-fan.org> - 1:2.0000-1.0
- Update to 2.0000
  - Fix warnings that appear when compiling using the clang C compiler by
    default (CPAN RT#77802)
  - Fix tests and run-time errors when Hash::FieldHash is installed by no
    longer using Hash::FieldHash (CPAN RT#77576)
- Update UTF-8 patch

* Thu May 31 2012 Paul Howarth <paul@city-fan.org> - 1:1.99-1.0
- Update to 1.99
  - Fix overloading
  - Fix test failures (and general functionality) on 64-bit big endian
    platforms (CPAN RT#77340)

* Thu May 24 2012 Paul Howarth <paul@city-fan.org> - 1:1.98-2.0
- Rebuild for libxml2 2.8.0

* Mon May 14 2012 Paul Howarth <paul@city-fan.org> - 1:1.98-1.0
- Update to 1.98
  - Make sure parse_string() and load_xml() also accept references to strings,
    to avoid unnecessary copying (CPAN RT#64051)

* Tue May  1 2012 Paul Howarth <paul@city-fan.org> - 1:1.97-1.0
- Update to 1.97
  - Apply a test and a fix to correct keep_blanks having no effect on
    parse_balanced_chunk (CPAN RT#76696)
  - Add t/30keep_blanks.t
- BR: perl(Data::Dumper)

* Fri Mar 16 2012 Paul Howarth <paul@city-fan.org> - 1:1.96-1.0
- Update to 1.96
  - Add leading minus signs to the commands of install_sax_driver, which makes
    the make process succeed even if they fail (CPAN RT#75007)
  - Skip t/49callbacks_returning_undef.t with perl(URI) < 1.35
    (http://www.city-fan.org/tips/PaulHowarth/Blog/2011-09-06)
- BR: perl(URI) unconditionally

* Tue Mar  6 2012 Paul Howarth <paul@city-fan.org> - 1:1.95-1.0
- Update to 1.95
  - Got rid of a broken test (at least with recent libxml2s) in t/03doc.t
    (CPAN RT#75403); the problem was that the test tested for an undefined XML
    namespace, a behaviour which was changed in a recent libxml2 release

* Sun Mar  4 2012 Paul Howarth <paul@city-fan.org> - 1:1.94-1.0
- Update to 1.94
  - Fix XML::LibXML::Element tests for inequality with == and eq
    (CPAN RT#75505)
- Don't need to remove empty directories from buildroot
- Drop support for distributions prior to FC-3:
  - Use %%{_fixperms} macro instead of our own chmod incantation
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Don't need LD_RUN_PATH kludge
  - Don't need to define %%{perl_vendorarch}
  - Run t/72destruction.t unconditionally

* Mon Feb 27 2012 Paul Howarth <paul@city-fan.org> - 1:1.93-1.0
- Update to 1.93
  - Fix XML::LibXML::Element comparision with == and eq
    (CPAN RT#75257, CPAN RT#75259, CPAN RT#75293)
- Enable thread test in %%check with perl 5.8.8 and above

* Tue Feb 21 2012 Paul Howarth <paul@city-fan.org> - 1:1.92-1.0
- Update to 1.92
  - Fix for test failure on perls < 5.10 (CPAN RT#75195)
- Drop patch for CPAN RT#75195
- Don't run t/72destruction.t on RHEL-3.x86_64 as it fails after passing all
  subtests

* Tue Feb 21 2012 Paul Howarth <paul@city-fan.org> - 1:1.91-1.0
- Update to 1.91
  - Overload hash dereferencing on XML::LibXML::Elements, to provide access to
    the element's attributes (see XML::LibXML::AttributeHash for details)
  - Add more convenient methods to XML::LibXML::NodeList such as sort, map,
    grep, etc.
  - Printed some warnings regardless if DEBUG is on
- Add patch to fix t/72destruction.t on Perl < 5.10 (CPAN RT#75195)

* Mon Jan  9 2012 Paul Howarth <paul@city-fan.org> - 1:1.90-1.0
- Update to 1.90
  - Fix compilation bugs in Devel.xs: local variable declarations must be in
    the PREINIT section, not CODE, at least for some compiler/OS combinations

* Sun Dec 25 2011 Paul Howarth <paul@city-fan.org> - 1:1.89-1.0
- Update to 1.89
  - Spelling fixes (CPAN RT#71403)
  - Add XML::LibXML::Devel
  - Adjust the Win32 build instructions in the README file

* Wed Sep 21 2011 Paul Howarth <paul@city-fan.org> - 1:1.88-1.0
- Update to 1.88
  - Add libxml2 2.7.8 as tested and working fine for the Makefile.PL
  - Apply a patch to perl-libxml-sax.c to use xmlChar * instead of char *
  - Correct the README so it doesn't refer to XML-LibXML-Common
    (see http://code.activestate.com/lists/perl-xml/8907/)
  - Add a patch to implement the no_defdtd option in recent libxml2 versions:
    (CPAN RT#70878)
  - Add scripts/bump-version-number.pl to modify the version number globally
    (previously the version numbers of the modules under lib/ were 1.73)

* Tue Sep  6 2011 Paul Howarth <paul@city-fan.org> - 1:1.87-1.0
- Update to 1.87
  - Fix t/49callbacks_returning_undef.t to not read /etc/passwd, which may not
    be valid XML; instead, we're reading a local file while using URI::file
    (assuming it exists - else we skip_all)
- BR: perl(URI::file) if a recent enough one is available

* Thu Aug 25 2011 Paul Howarth <paul@city-fan.org> - 1:1.86-1.0
- Update to 1.86
  - Changed SvPVx_nolen() to SvPV_nolen() in LibXML.xs for better
    compatibility; SvPVx_nolen() appears to be undocumented API (CPAN RT#70476)
- Drop now-redundant patch for CPAN RT#70476

* Thu Aug 25 2011 Paul Howarth <paul@city-fan.org> - 1:1.85-1.0
- Update to 1.85
  - Gracefully handle returned undef()s in the read callback under -w ($^W);
    add t/49callbacks_returning_undef.t (CPAN RT#70321)
  - Add a patch from Mithaldu to get XML::LibXML to compile on Win32:
    (CPAN RT#70141)
- Add patch to fix missing symbol SvPVx_nolen on Perl < 5.8.8 (CPAN RT#70476)

* Sat Jul 23 2011 Paul Howarth <paul@city-fan.org> - 1:1.84-2.0
- Rebuild for perl 5.14.1 in Rawhide

* Sat Jul 23 2011 Paul Howarth <paul@city-fan.org> - 1:1.84-1.0
- Update to 1.84
  - Fix for perl 5.8.x before 5.8.8 (CPAN RT#69722)
- Drop upstreamed perl 5.8.8 patch

* Sat Jul 23 2011 Paul Howarth <paul@city-fan.org> - 1:1.83-1.0
- Update to 1.83
  - Fixed missing declarations after statements (CPAN RT#69622)
  - Fix docbook source validity (CPAN RT#69702)
  - Documentation spelling fixes (CPAN RT#69703)
  - Convert t/14sax.t to Counter and Stacker so the tests will be more reliable
- Add patch so we can pass the test suite with perl < 5.8.8 (CPAN RT#69722)
- Remove rpaths on distributions older than Fedora Core 2

* Thu Jul 21 2011 Paul Howarth <paul@city-fan.org> - 1:1.82-1.0
- Update to 1.82
  - Moved some if blocks after the dSP; (which contains declarations) to be
    compliant with C89/C90, which don't allow declarations in the middle of
    a C function (CPAN RT#69622)
  - CPAN RT#69553: install_sax_driver doesn't like custom INSTALLARCHLIB

* Sat Jul 16 2011 Paul Howarth <paul@city-fan.org> - 1:1.81-1.0
- Update to 1.81
  - Add scripts/fast-eumm.pl to remove the explicit objects dependency on the
    "Makefile" file so after running scripts/fast-eumm.pl one won't have to
    rebuild the C-files
  - Add no warnings 'recursion' to lib/XML/LibXML/Error.pm to get rid of a
    "Deep recursion" warning
  - Fix "IDs of elements is lost when importing nodes" (CPAN RT#69520) and add
    t/48importing_nodes_IDs_rt_69520.t
  - Convert all remaining Test.pm-based test scripts except t/14sax.t to
    Test::More

* Wed Jul 13 2011 Paul Howarth <paul@city-fan.org> - 1:1.80-1.0
- Update to 1.80
  - Fix compilation on strawberry perl (CPAN RT#69082)
  - DOM Normalisation patches and fix for findvalue regression (CPAN RT#69096)
  - t/19die_on_invalid_utf8_rt_58848.t assumed errors would be objects,
    causing failures with old libxml versions (CPAN RT#69433)
  - Add a skip for t/60error_prev_chain.t in case $@ is true but not a ref
    (CPAN RT#69435)
- Fix dist tag for CentOS 6 and Scientific Linux
- Fix bogus exec permissions on source files

* Fri Jul  8 2011 Paul Howarth <paul@city-fan.org> - 1:1.79-1.0
- Update to 1.79
  - In t/46err_column.t, add a skip for a test for CentOS/RHEL 4 with an old
    version of libxml2 (CPAN RT#69070)
  - In t/49global_extent.t, fix the double plan present on libxml2 below
    2.6.27 (CPAN RT#69330)
  - Fix double plan in t/61error.t in accordance with the previous change

* Thu Jul  7 2011 Paul Howarth <paul@city-fan.org> - 1:1.78-1.0
- Update to 1.78
  - Change t/02parse.t to test for the localized error message (CPAN RT#69248)
  - Fix the skip() and 'plan skip_all' syntax in t/06elements.t and
    t/49global_extent.t
  - Convert more test scripts from Test.pm to Test::More

* Sat Jul  2 2011 Paul Howarth <paul@city-fan.org> - 1:1.77-1.0
- Update to 1.77
  - Change the signature of XML::LibXML::Reader::byteConsumed to be "long"
    instead of "int", so it can return values above 2**31 in 64-bit platforms
    (should fix CPAN RT#57085)
  - Change "a XML::LibXML::*" to "an XML::LibXML::*" in the documentation
  - Document XML::LibXML::NamedNodeMap (CPAN RT#57652)
  - Add an external entity resolver for XSLT/etc. (CPAN RT#69166)
  - Add the missing string comparison overload in lib/XML/LibXML/NodeList.pm
    (CPAN RT#57737)
  - Fix CPAN RT#58024: In XML::LibXML, warnings are not suppressed when
    specifying the recover() or recover_silently() flags
  - Now XML-LibXML requires perl-5.8.x (to print to a buffer)
  - Fix CPAN RT#56671: Limit the length of the chain of the previous errors
    (adds new files t/60error_prev_chain.t and example/JBR-ALLENtrees.htm)
  - Fix CPAN RT#58848: "Malformed UTF-8 character (fatal) at" exception thrown
    on invalid UTF-8

* Fri Jul  1 2011 Paul Howarth <paul@city-fan.org> - 1:1.76-1.0
- Update to 1.76
  - Cleaned up t/28new_callbacks_multiple.t - convert to a Counter and Stacker
    class
  - After that, the regression test for it was added (CPAN RT#51086)
  - Add the file HACKING.txt with style guidelines
  - Fix CPAN RT#53270 (suppress_errors option not honored by load_html() method
    if set in parser object), with a test in t/49_load_html.t
  - Uncovered some more bugs, documented in TODO
  - Created t/lib/TestHelpers.pm with slurp(), utf8_slurp() and, in the future,
    some other routines
  - Skipping for LIBXML_RUNTIME_VERSION() *less than* 2.7 instead of
    *more than* in t/09xpath.t (CPAN RT#69205)

* Fri Jun 24 2011 Paul Howarth <paul@city-fan.org> - 1:1.75-1.0
- Update to 1.75
  - Correct some typos (CPAN RT#54390)
  - Fix the handling of XML::LibXML::InputCallbacks at load_xml()
    (CPAN RT#58190)
  - Convert t/02parse.t to Test::More and remove annoying diag() messages
    (CPAN RT#56334)
  - Add 'make runtest' and 'make distruntest' targets to run the tests using
    Test::Run (adds colours and stuff like that)
  - Add << LICENSE => 'perl' >> to the Makefile.PL for a license
    meta-data in the META.YML.
  - Feature implementation: joining congruent character data together in
    SAX driver (CPAN RT#52368)
  - Add t/pod.t
  - Fix CPAN RT#55000: if an element contains both a default namespace
    declaration and a second namespace declaration, adding an attribute using
    the default namespace declaration will cause that attribute to have the
    other prefix
- BR: perl(Test::Pod)

* Thu Jun 23 2011 Paul Howarth <paul@city-fan.org> - 1:1.74-1.0
- Update to 1.74
  - More work on the t/*.t test scripts
  - Add scripts/Test.pm-to-Test-More.pl to semi-automatically convert a test
     script from Test.pm to Test::More
  - Change NodeSet to NodeList in the documentation of
    lib/XML/LibXML/NodeList.pm (CPAN RT#60998)
  - Makefile.PL: make clear that we are trying to link against libm, libz and
    libxml2 and not just libxml2 (CPAN RT#51439)
  - Fix documentation for XML::LibXML::Comment (CPAN RT#61756)
  - Documentation: moved away from Indirect-object-notation and added some
    missing "my"s
  - Fix failing t/01basic.t when compiling against libxml2 that comes from git
    (CPAN RT#54951)

* Sat Jun 18 2011 Paul Howarth <paul@city-fan.org> - 1:1.73-1.0
- Update to 1.73
  - calculating $err->column() properly, so it won't be maxed out at 80
    (CPAN RT#66642)
  - update the repository in the documentation to point to the bitbucket.org one
  - revamped Makefile.PL:
    - got rid of "\t" characters
    - add "use strict" and "use warnings"
    - add resources and keywords to the META_MERGE
    - other changes
  - fix CPAN RT#53632: when calling normalize on a node, processing of children
    nodes will stop when an empty element node is encountered
  - apply the patch from Daniel Fetter's InputCallbackFix branch:
    - a partial fix to CPAN RT#4263)
    - call two $parser->parse_string() in succession
  - apply the NestedParsing patch (more of CPAN RT#4263):
    - updated how legacy parser local callbacks are utilized by init_callbacks
      so that the XML::LibXML::InputCallback object doesn't have to be
      temporarily modified during the parsing process; this change could break
      code for users that have subclassed XML::LibXML::InputCallback and
      overridden the init_callbacks method
  - documentation fixes patch from Daniel Fetter

* Thu Jun 16 2011 Paul Howarth <paul@city-fan.org> - 1:1.72-1.0
- Update to 1.72
  - removed a stray file from the MANIFEST, causing a "kit not complete"
    warning (CPAN RT#68865)

* Tue Jun 14 2011 Paul Howarth <paul@city-fan.org> - 1:1.71-1.0
- Update to 1.71
  - turn XML_LIBXML_PARSE_DEFAULTS constant to
    $XML::LibXML::XML_LIBXML_PARSE_DEFAULTS
  - no need to AUTOLOAD 'domain' because a method like that exists
    (CPAN RT#68575)
  - get rid of AUTOLOAD completely (CPAN RT#68575)
  - handle unknown domains (CPAN RT#68575)
  - add more errors (CPAN RT#68575)
  - avoid malformed UTF-8 warnings (CPAN RT#68575)
  - in replaceDataString - use http://perldoc.perl.org/functions/quotemeta.html
    instead of a long (and incomplete) list of characters to escape
    (CPAN RT#68564)
  - also fix deleteDataString by making it use replaceDataString for help
- This release by SHLOMIF -> update source URL
- Use a patch rather than iconv to fix documentation character encoding
- Nobody else likes macros for commands
- Package TODO
- Obsolete/Provide perl-XML-LibXML-XPathContext

* Fri Nov  5 2010 Paul Howarth <paul@city-fan.org> - 1:1.70-7.0
- Rebuild for libxml2 2.7.8

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 1:1.70-6.0
- Rebuild for perl 5.12.1 in Rawhide

* Thu May 27 2010 Paul Howarth <paul@city-fan.org> - 1:1.70-5.0
- Fix dist tag for RHEL-6 Beta
- Large release bump to overtake EL-6 package built against libxml 2.7.6

* Thu Feb 25 2010 Paul Howarth <paul@city-fan.org> - 1:1.70-2
- Dist tag for Rawhide no longer needs special-casing

* Thu Oct  8 2009 Paul Howarth <paul@city-fan.org> - 1:1.70-1
- Update to 1.70
  - merge with XML::LibXML::Common
  - various fixes and improvements in the documentation
  - added (convenient yet non-standard) methods nonBlankChildNodes,
    firstNonBlankChild, nextNonBlankSibling, prevNonBlankSibling that skip
    empty or whitespace-only Text and CDATA nodes
  - exposed and documented external entity handler
  - XPathContext can now be passed to toStringC14N and toStringEC14N
  - avoid using libxml2's globals
  - added interface to libxml2's regexp implementation: XML::LibXML::RegExp
  - added XML::LibXML->load_xml and XML::LibXML->load_html with uniform and
    cleaner API than the old parse_* family
  - cleanup code dealing with parsing flags
  - fix bogus validation results if revalidating a modified document
  - added 'eq' and 'cmp' overloading on XML::LibXML::Error; set fallback to 1
  - lots of bugs fixed
  - provide context and more accurate column number in structured errors
  - clarify license and copyright
  - fix compilation bugs
  - fix encoding problem in reader
  - added getAttributeHash to the reader interface
  - fix segfaults: reconcileNs in domReplaceChild, findnodes with a doc fragment
- Obsolete/Provide perl-XML-LibXML-Common
- Don't buildreq perl(XML::LibXML::Common)
- Bump libxml2 version requirement to 2.7.6
- Bump XML::LibXSLT non-conflict requirement to 1.70
- Drop upstreamed test patch

* Mon Sep 28 2009 Paul Howarth <paul@city-fan.org> - 1:1.69-3
- Use %%{?perl_default_filter} for provides filter
- Add patch for bogus encoding test t/03_doc.t
  (http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=546240)

* Fri Mar  6 2009 Paul Howarth <paul@city-fan.org> - 1:1.69-2
- Filter out unwanted provides for perl shared objects
- Update to SLES-compatible dist tag macros

* Wed Nov 12 2008 Paul Howarth <paul@city-fan.org> - 1:1.69-1
- Update to 1.69

* Mon Nov 10 2008 Paul Howarth <paul@city-fan.org> - 1:1.68-1
- Update to 1.68

* Wed Nov  5 2008 Paul Howarth <paul@city-fan.org> - 1:1.67-1
- Update to 1.67
- Add note about perl-XML-LibXSLT having to be the same version due to code
  sharing between the two modules (#469480)
- Conflict with incompatible perl-XML-LibXSLT versions
- New modules XML::LibXML::{Pattern,XPathExpression}
- New manpages for XML::LibXML::{ErrNo,Error,Pattern,XPathExpression}

* Fri Oct 31 2008 Paul Howarth <paul@city-fan.org> - 1:1.66-1
- Update to 1.66 (will build current libxml2 for old distributions)
- Add epoch for upgrade path from 1.62001
- Clarify license as GPL version 1 or later, or Artistic (i.e. same as perl)
- Tweak dist tag macros to work on current Rawhide with three-part releasenum
- Recode Changes as UTF8
- Enable test suite
- Suppress warning about nonexistent file in perl-XML-SAX install trigger
- New upstream maintainer -> URL change for source
- Make %%files list more explicit
- Require and BuildRequire libxml2 >= 2.6.21
- Add buildreq perl(Test::More)

* Mon Mar 26 2007 Paul Howarth <paul@city-fan.org> - 1.57-3
- Import from Fedora Core
- Downgrade to 1.57 for compatibility with old libxml2 versions
- Improve package description
- Include dist tag macros
- Use Fedora standard buildroot
- BuildRequire perl(ExtUtils::MakeMaker)
- Use perl(...) style dependencies
- Remove old spec file cruft
- Macro-ize commands where possible, hardcode paths elsewhere

* Thu Dec 07 2006 Robin Norwood <rnorwood@redhat.com> - 1.62001-2
- Rebuild

* Sat Dec 02 2006 Robin Norwood <rnorwood@redhat.com> - 1.62001
- Build latest version from CPAN: 1.62001

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 1.58-2.2.2.1
- rebuild

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 1.58-2.2.2
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 1.58-2.2.1
- rebuilt for new gcc4.1 snapshot and glibc changes

* Fri Feb 03 2006 Jason Vas Dias <jvdias@redhat.com> - 1.58-2.2
- rebuild for new perl-5.8.8

* Fri Dec 16 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt for new gcc

* Fri Dec 16 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt for new gcj

* Sat Mar 19 2005 Joe Orton <jorton@redhat.com> 1.58-2
- rebuild

* Sun Apr 18 2004 Ville Skyttä <ville.skytta at iki.fi> - 1.58-1
- #121168
- Update to 1.58.
- Require perl(:MODULE_COMPAT_*).
- Handle ParserDetails.ini parser registration.
- BuildRequires libxml2-devel.
- Own installed directories.

* Fri Feb 27 2004 Chip Turner <cturner@redhat.com> - 1.56-1
- Specfile autogenerated.
